# hn_data_stock/finance_data.py

# import requests
# import yfinance as yf

# def get_stock_data(ticker):

#     # Lấy dữ liệu cổ phiếu Apple
#     history = yf.Ticker(ticker)
#     # Lấy dữ liệu giá trong vòng period tháng gần nhất
#     history_data = history.history(period='1mo')
    
#     return history_data